<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>ActionsShortcutsModel</name>
    <message>
        <location filename="../shortcuts_management/actions_shortcuts_model.cpp" line="73"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <location filename="bookmarks_dialog.cpp" line="75"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="107"/>
        <location filename="bookmarks_dialog.cpp" line="124"/>
        <source>Loading...</source>
        <translation>Inladen...</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="85"/>
        <source>Click on any image to go to the bookmark</source>
        <translation>Klik op een afbeelding om naar de bladwijzer te gaan </translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="25"/>
        <source>Lastest Page</source>
        <translation>Laatste Pagina</translation>
    </message>
</context>
<context>
    <name>EditShortcutsDialog</name>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="23"/>
        <source>Restore defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="24"/>
        <source>To change a shortcut, double click in the key combination and type the new keys.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="71"/>
        <source>Shortcuts settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>Shortcut in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>The shortcut &quot;%1&quot; is already assigned to other function</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="562"/>
        <source>7z not found</source>
        <translation>7Z Archiefbestand niet gevonden</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="454"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="461"/>
        <source>Unknown error opening the file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="568"/>
        <source>Format not supported</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GoToDialog</name>
    <message>
        <location filename="goto_dialog.cpp" line="23"/>
        <source>Go To</source>
        <translation>Ga Naar</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="53"/>
        <source>Go to...</source>
        <translation>Ga naar...</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="39"/>
        <location filename="goto_dialog.cpp" line="71"/>
        <source>Total pages : </source>
        <translation>Totaal aantal pagina&apos;s : </translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="25"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="15"/>
        <source>Page : </source>
        <translation>Pagina : </translation>
    </message>
</context>
<context>
    <name>GoToFlowToolBar</name>
    <message>
        <location filename="goto_flow_toolbar.cpp" line="38"/>
        <source>Page : </source>
        <translation>Pagina : </translation>
    </message>
</context>
<context>
    <name>HelpAboutDialog</name>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="30"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="33"/>
        <source>System info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="27"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="14"/>
        <source>Log window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="22"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="39"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="56"/>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="73"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="90"/>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="136"/>
        <source>&amp;Auto scroll</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowViewer</name>
    <message>
        <source>Help</source>
        <translation type="vanished">Help</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Bewaar</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="vanished">&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="vanished">&amp;Volgende</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">&amp;Open</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Sluiten</translation>
    </message>
    <message>
        <source>Open Comic</source>
        <translation type="vanished">Open een Strip</translation>
    </message>
    <message>
        <source>Go To</source>
        <translation type="vanished">Ga Naar</translation>
    </message>
    <message>
        <source>Open image folder</source>
        <translation type="vanished">Open afbeeldings map</translation>
    </message>
    <message>
        <source>Set bookmark</source>
        <translation type="vanished">Bladwijzer instellen</translation>
    </message>
    <message>
        <source>page_%1.jpg</source>
        <translation type="vanished">pagina_%1.jpg</translation>
    </message>
    <message>
        <source>Switch to double page mode</source>
        <translation type="vanished">Naar dubbele bladzijde modus</translation>
    </message>
    <message>
        <source>Save current page</source>
        <translation type="vanished">Bewaren huidige pagina</translation>
    </message>
    <message>
        <source>Double page mode</source>
        <translation type="vanished">Dubbele bladzijde modus</translation>
    </message>
    <message>
        <source>Switch Magnifying glass</source>
        <translation type="vanished">Overschakelen naar Vergrootglas</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="vanished">Map Openen</translation>
    </message>
    <message>
        <source>Comic files</source>
        <translation type="vanished">Strip bestanden</translation>
    </message>
    <message>
        <source>Go to previous page</source>
        <translation type="vanished">Ga naar de vorige pagina</translation>
    </message>
    <message>
        <source>Open a comic</source>
        <translation type="vanished">Open een strip</translation>
    </message>
    <message>
        <source>Image files (*.jpg)</source>
        <translation type="vanished">Afbeelding bestanden (*.jpg)</translation>
    </message>
    <message>
        <source>Next Comic</source>
        <translation type="vanished">Volgende Strip</translation>
    </message>
    <message>
        <source>Fit Width</source>
        <translation type="vanished">Vensterbreedte aanpassen</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="vanished">Opties</translation>
    </message>
    <message>
        <source>Show Info</source>
        <translation type="vanished">Info tonen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Open een Map</translation>
    </message>
    <message>
        <source>Go to page ...</source>
        <translation type="vanished">Ga naar bladzijde ...</translation>
    </message>
    <message>
        <source>Fit image to width</source>
        <translation type="vanished">Afbeelding aanpassen aan breedte</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="vanished">&amp;Vorige</translation>
    </message>
    <message>
        <source>Go to next page</source>
        <translation type="vanished">Ga naar de volgende pagina</translation>
    </message>
    <message>
        <source>Show keyboard shortcuts</source>
        <translation type="vanished">Toon de sneltoetsen</translation>
    </message>
    <message>
        <source>There is a new version available</source>
        <translation type="vanished">Er is een nieuwe versie beschikbaar</translation>
    </message>
    <message>
        <source>Open next comic</source>
        <translation type="vanished">Open volgende strip</translation>
    </message>
    <message>
        <source>Show bookmarks</source>
        <translation type="vanished">Bladwijzers weergeven</translation>
    </message>
    <message>
        <source>Open previous comic</source>
        <translation type="vanished">Open de vorige strip</translation>
    </message>
    <message>
        <source>Rotate image to the left</source>
        <translation type="vanished">Links omdraaien</translation>
    </message>
    <message>
        <source>Fit image to height</source>
        <translation type="vanished">Afbeelding aanpassen aan hoogte</translation>
    </message>
    <message>
        <source>Show the bookmarks of the current comic</source>
        <translation type="vanished">Toon de bladwijzers van de huidige strip</translation>
    </message>
    <message>
        <source>Show Dictionary</source>
        <translation type="vanished">Woordenlijst weergeven</translation>
    </message>
    <message>
        <source>YACReader options</source>
        <translation type="vanished">YACReader opties</translation>
    </message>
    <message>
        <source>Help, About YACReader</source>
        <translation type="vanished">Help, Over YACReader</translation>
    </message>
    <message>
        <source>Show go to flow</source>
        <translation type="vanished">Toon ga naar de Omslagbrowser</translation>
    </message>
    <message>
        <source>Previous Comic</source>
        <translation type="vanished">Vorige Strip</translation>
    </message>
    <message>
        <source>Show full size</source>
        <translation type="vanished">Volledig Scherm </translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation type="vanished">Vergrootglas</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Algemeen</translation>
    </message>
    <message>
        <source>Set a bookmark on the current page</source>
        <translation type="vanished">Een bladwijzer toevoegen aan de huidige pagina</translation>
    </message>
    <message>
        <source>Do you want to download the new version?</source>
        <translation type="vanished">Wilt u de nieuwe versie downloaden?</translation>
    </message>
    <message>
        <source>Rotate image to the right</source>
        <translation type="vanished">Rechts omdraaien</translation>
    </message>
    <message>
        <source>Always on top</source>
        <translation type="vanished">Altijd op voorgrond</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="options_dialog.cpp" line="145"/>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="149"/>
        <source>Reset</source>
        <translation>Standaardwaarden terugzetten</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="34"/>
        <source>My comics path</source>
        <translation>Pad naar mijn strips</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="193"/>
        <source>Image adjustment</source>
        <translation>Beeldaanpassing</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="43"/>
        <source>&quot;Go to flow&quot; size</source>
        <translation>&quot;Naar Omslagbrowser&quot; afmetingen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="64"/>
        <source>Choose</source>
        <translation>Kies</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="154"/>
        <source>Image options</source>
        <translation>Afbeelding opties</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="144"/>
        <source>Contrast</source>
        <translation>Contrast</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="208"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="215"/>
        <source>Comics directory</source>
        <translation>Strips map</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="61"/>
        <source>Background color</source>
        <translation>Achtergrondkleur</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="192"/>
        <source>Page Flow</source>
        <translation>Omslagbrowser</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="191"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="143"/>
        <source>Brightness</source>
        <translation>Helderheid</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="199"/>
        <source>Restart is needed</source>
        <translation>Herstart is nodig</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="99"/>
        <source>Quick Navigation Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="71"/>
        <source>Scroll behaviour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="74"/>
        <source>Disable scroll animations and smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="75"/>
        <source>Do not turn page using scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="76"/>
        <source>Use single scroll step to turn page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="100"/>
        <source>Disable mouse over activation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="158"/>
        <source>Fit options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="160"/>
        <source>Enlarge images to fit width/height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="171"/>
        <source>Double Page options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="173"/>
        <source>Show covers as single page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>7z lib not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>unable to load 7z lib from ./utils</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="41"/>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="43"/>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="45"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="47"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="49"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="51"/>
        <source>Fatal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::LogWindowModel</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="141"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="143"/>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="145"/>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::Window</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="236"/>
        <source>Save log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="237"/>
        <source>Log file (*.log)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutsDialog</name>
    <message>
        <source>Close</source>
        <translation type="vanished">Sluiten</translation>
    </message>
    <message>
        <source>YACReader keyboard shortcuts</source>
        <translation type="vanished">YACReader sneltoetsen</translation>
    </message>
    <message>
        <source>Keyboard Shortcuts</source>
        <translation type="vanished">Sneltoetsen</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="viewer.cpp" line="51"/>
        <location filename="viewer.cpp" line="924"/>
        <source>Press &apos;O&apos; to open comic.</source>
        <translation>Druk &apos;O&apos; om een strip te openen.</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1128"/>
        <source>Cover!</source>
        <translation>Omslag!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="234"/>
        <source>Comic not found</source>
        <translation>Strip niet gevonden</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="234"/>
        <source>Not found</source>
        <translation>Niet gevonden</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1142"/>
        <source>Last page!</source>
        <translation>Laatste pagina!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="936"/>
        <source>Loading...please wait!</source>
        <translation>Inladen...even wachten!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="240"/>
        <source>Error opening comic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="246"/>
        <source>CRC Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="946"/>
        <source>Page not available!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YACReader::MainWindowViewer</name>
    <message>
        <location filename="main_window_viewer.cpp" line="183"/>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Open</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="185"/>
        <source>Open a comic</source>
        <translation type="unfinished">Open een strip</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="191"/>
        <source>New instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="210"/>
        <source>Open Folder</source>
        <translation type="unfinished">Map Openen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="212"/>
        <source>Open image folder</source>
        <translation type="unfinished">Open afbeeldings map</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="217"/>
        <source>Open latest comic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="218"/>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="230"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="231"/>
        <source>Clear open recent list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="234"/>
        <source>Save</source>
        <translation type="unfinished">Bewaar</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="236"/>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>Save current page</source>
        <translation type="unfinished">Bewaren huidige pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="241"/>
        <source>Previous Comic</source>
        <translation type="unfinished">Vorige Strip</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="243"/>
        <location filename="main_window_viewer.cpp" line="1641"/>
        <location filename="main_window_viewer.cpp" line="1645"/>
        <source>Open previous comic</source>
        <translation type="unfinished">Open de vorige strip</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="248"/>
        <source>Next Comic</source>
        <translation type="unfinished">Volgende Strip</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="250"/>
        <location filename="main_window_viewer.cpp" line="1640"/>
        <location filename="main_window_viewer.cpp" line="1646"/>
        <source>Open next comic</source>
        <translation type="unfinished">Open volgende strip</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="255"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Vorige</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="258"/>
        <location filename="main_window_viewer.cpp" line="1643"/>
        <location filename="main_window_viewer.cpp" line="1647"/>
        <source>Go to previous page</source>
        <translation type="unfinished">Ga naar de vorige pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="263"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Volgende</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="266"/>
        <location filename="main_window_viewer.cpp" line="1642"/>
        <location filename="main_window_viewer.cpp" line="1648"/>
        <source>Go to next page</source>
        <translation type="unfinished">Ga naar de volgende pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="271"/>
        <source>Fit Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="274"/>
        <source>Fit image to height</source>
        <translation type="unfinished">Afbeelding aanpassen aan hoogte</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="281"/>
        <source>Fit Width</source>
        <translation type="unfinished">Vensterbreedte aanpassen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="284"/>
        <source>Fit image to width</source>
        <translation type="unfinished">Afbeelding aanpassen aan breedte</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="291"/>
        <source>Show full size</source>
        <translation type="unfinished">Volledig Scherm </translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="299"/>
        <source>Fit to page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="330"/>
        <source>Reset zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="335"/>
        <source>Show zoom slider</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="338"/>
        <source>Zoom+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="343"/>
        <source>Zoom-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="348"/>
        <source>Rotate image to the left</source>
        <translation type="unfinished">Links omdraaien</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="354"/>
        <source>Rotate image to the right</source>
        <translation type="unfinished">Rechts omdraaien</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="360"/>
        <source>Double page mode</source>
        <translation type="unfinished">Dubbele bladzijde modus</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="361"/>
        <source>Switch to double page mode</source>
        <translation type="unfinished">Naar dubbele bladzijde modus</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="370"/>
        <source>Double page manga mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="371"/>
        <source>Reverse reading order in double page mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="380"/>
        <source>Go To</source>
        <translation type="unfinished">Ga Naar</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="382"/>
        <source>Go to page ...</source>
        <translation type="unfinished">Ga naar bladzijde ...</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="387"/>
        <source>Options</source>
        <translation type="unfinished">Opties</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="388"/>
        <source>YACReader options</source>
        <translation type="unfinished">YACReader opties</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="395"/>
        <location filename="main_window_viewer.cpp" line="689"/>
        <source>Help</source>
        <translation type="unfinished">Help</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="396"/>
        <source>Help, About YACReader</source>
        <translation type="unfinished">Help, Over YACReader</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="402"/>
        <source>Magnifying glass</source>
        <translation type="unfinished">Vergrootglas</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="403"/>
        <source>Switch Magnifying glass</source>
        <translation type="unfinished">Overschakelen naar Vergrootglas</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="410"/>
        <source>Set bookmark</source>
        <translation type="unfinished">Bladwijzer instellen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="411"/>
        <source>Set a bookmark on the current page</source>
        <translation type="unfinished">Een bladwijzer toevoegen aan de huidige pagina</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="420"/>
        <source>Show bookmarks</source>
        <translation type="unfinished">Bladwijzers weergeven</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="421"/>
        <source>Show the bookmarks of the current comic</source>
        <translation type="unfinished">Toon de bladwijzers van de huidige strip</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="427"/>
        <source>Show keyboard shortcuts</source>
        <translation type="unfinished">Toon de sneltoetsen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="433"/>
        <source>Show Info</source>
        <translation type="unfinished">Info tonen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="439"/>
        <source>Close</source>
        <translation type="unfinished">Sluiten</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="445"/>
        <source>Show Dictionary</source>
        <translation type="unfinished">Woordenlijst weergeven</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="452"/>
        <source>Show go to flow</source>
        <translation type="unfinished">Toon ga naar de Omslagbrowser</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="458"/>
        <source>Edit shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="481"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Bestand</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="493"/>
        <location filename="main_window_viewer.cpp" line="644"/>
        <source>Open recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="633"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="654"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="658"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="674"/>
        <source>Go</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="682"/>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="783"/>
        <location filename="main_window_viewer.cpp" line="785"/>
        <source>Open Comic</source>
        <translation type="unfinished">Open een Strip</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="783"/>
        <location filename="main_window_viewer.cpp" line="785"/>
        <source>Comic files</source>
        <translation type="unfinished">Strip bestanden</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="876"/>
        <source>Open folder</source>
        <translation type="unfinished">Open een Map</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>page_%1.jpg</source>
        <translation type="unfinished">pagina_%1.jpg</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>Image files (*.jpg)</source>
        <translation type="unfinished">Afbeelding bestanden (*.jpg)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1137"/>
        <source>Comics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1147"/>
        <source>Toggle fullscreen mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1150"/>
        <source>Hide/show toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1153"/>
        <source>General</source>
        <translation type="unfinished">Algemeen</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1172"/>
        <source>Size up magnifying glass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1175"/>
        <source>Size down magnifying glass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1178"/>
        <source>Zoom in magnifying glass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1181"/>
        <source>Zoom out magnifying glass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1187"/>
        <source>Magnifiying glass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1194"/>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1198"/>
        <source>Page adjustement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1215"/>
        <source>Autoscroll down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1218"/>
        <source>Autoscroll up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1221"/>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1225"/>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1229"/>
        <source>Autoscroll forward, vertical first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1233"/>
        <source>Autoscroll backward, vertical first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1237"/>
        <source>Move down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1240"/>
        <source>Move up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1243"/>
        <source>Move left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1246"/>
        <source>Move right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1249"/>
        <source>Go to the first page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1252"/>
        <source>Go to the last page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1255"/>
        <source>Offset double page to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1257"/>
        <source>Offset double page to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1275"/>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1320"/>
        <source>There is a new version available</source>
        <translation type="unfinished">Er is een nieuwe versie beschikbaar</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1321"/>
        <source>Do you want to download the new version?</source>
        <translation type="unfinished">Wilt u de nieuwe versie downloaden?</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1324"/>
        <source>Remind me in 14 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1325"/>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YACReader::WhatsNewDialog</name>
    <message>
        <location filename="../custom_widgets/whats_new_dialog.cpp" line="115"/>
        <source>Close</source>
        <translation type="unfinished">Sluiten</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="11"/>
        <source>Restore to default</source>
        <translation>Standaardwaarden herstellen</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="28"/>
        <source>Click to overwrite</source>
        <translation>Klik hier om te overschrijven</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldPlainTextEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="10"/>
        <source>Restore to default</source>
        <translation>Standaardwaarden herstellen</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="19"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="44"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="50"/>
        <source>Click to overwrite</source>
        <translation>Klik hier om te overschrijven</translation>
    </message>
</context>
<context>
    <name>YACReaderFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="15"/>
        <source>CoverFlow look</source>
        <translation>Omslagbrowser uiterlijk </translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="13"/>
        <source>How to show covers:</source>
        <translation>Omslagbladen bekijken:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="16"/>
        <source>Stripe look</source>
        <translation>Brede band </translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="17"/>
        <source>Overlapped Stripe look</source>
        <translation>Overlappende band</translation>
    </message>
</context>
<context>
    <name>YACReaderGLFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="112"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="142"/>
        <source>Light</source>
        <translation>Licht</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="76"/>
        <source>Show advanced settings</source>
        <translation>Toon geavanceerde instellingen</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="32"/>
        <source>Roulette look</source>
        <translation>Roulette</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="130"/>
        <source>Cover Angle</source>
        <translation>Omslag hoek</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="23"/>
        <source>Stripe look</source>
        <translation>Brede band</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="94"/>
        <source>Position</source>
        <translation>Positie</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="124"/>
        <source>Z offset</source>
        <translation>Z- positie</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="118"/>
        <source>Y offset</source>
        <translation>Y-positie</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="106"/>
        <source>Central gap</source>
        <translation>Centrale ruimte</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="18"/>
        <source>Presets:</source>
        <translation>Voorinstellingen:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="26"/>
        <source>Overlapped Stripe look</source>
        <translation>Overlappende band</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="29"/>
        <source>Modern look</source>
        <translation>Modern</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="88"/>
        <source>View angle</source>
        <translation>Kijkhoek</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="148"/>
        <source>Max angle</source>
        <translation>Maximale hoek</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="85"/>
        <source>Custom:</source>
        <translation>Aangepast:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="20"/>
        <source>Classic look</source>
        <translation>Klassiek</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="100"/>
        <source>Cover gap</source>
        <translation>Ruimte tss Omslag</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="182"/>
        <source>High Performance</source>
        <translation>Hoge Prestaties</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="201"/>
        <source>Performance:</source>
        <translation>Prestatie:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="193"/>
        <source>Use VSync (improve the image quality in fullscreen mode, worse performance)</source>
        <translation>Gebruik VSync (verbetering van de beeldkwaliteit in de modus volledig scherm, slechtere prestatie)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="136"/>
        <source>Visibility</source>
        <translation>Zichtbaarheid</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="180"/>
        <source>Low Performance</source>
        <translation>Lage Prestaties</translation>
    </message>
</context>
<context>
    <name>YACReaderOptionsDialog</name>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Bewaar</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="46"/>
        <source>Use hardware acceleration (restart needed)</source>
        <translation>Gebruik hardware versnelling (opnieuw opstarten vereist)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="34"/>
        <source>Edit shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="37"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YACReaderSlider</name>
    <message>
        <location filename="width_slider.cpp" line="49"/>
        <source>Reset</source>
        <translation>Standaardwaarden terugzetten</translation>
    </message>
</context>
<context>
    <name>YACReaderTranslator</name>
    <message>
        <location filename="translator.cpp" line="62"/>
        <source>YACReader translator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="translator.cpp" line="116"/>
        <location filename="translator.cpp" line="207"/>
        <source>Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="translator.cpp" line="139"/>
        <source>clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="translator.cpp" line="216"/>
        <source>Service not available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
